==> IsoplotR_1.3.tar.gz: IsoplotR/README.md <==
# IsoplotR

**IsoplotR** is a free and open-source substitute for Kenneth Ludwig's popular **Isoplot** add-in to Microsoft Excel. 
This Github repository contains the code for IsoplotR's core commands. A graphical user interface is provided
in a separate repository at [https://github.com/pvermees/IsoplotRgui](https://github.com/pvermees/IsoplotRgui).

## Prerequisites

You must have **R** installed on your system (see [http://r-project.org](http://r-project.org)). 
Additionally, to install IsoplotR from Github, you also need the **devtools** package.
This can be installed by typing the following code at the R command line prompt:

```
install.packages('devtools')
```

## Installation

The most recent stable version of IsoplotR is available from **CRAN** at
[https://cran.r-project.org/package=IsoplotR](https://cran.r-project.org/package=IsoplotR)
and can be installed on your system as follows:

```
install.packages('IsoplotR')
```

Alternatively, to install the current development version of IsoplotR from Github, type:

```
library(devtools)
install_github('pvermees/IsoplotR')
```

## Further information

See [http://isoplotr.london-geochron.com](http://isoplotr.london-geochron.com)

[Vermeesch, P., 2018, IsoplotR: a free and open toolbox for
geochronology. Geoscience Frontiers, doi: 10.1016/j.gsf.2018.04.001
(in press).](http://www.ucl.ac.uk/~ucfbpve/papers/VermeeschGSF2018/)

## Author

[Pieter Vermeesch](http://pieter.london-geochron.com)

## License

This project is licensed under the GPL-3 License

==> IsoplotR_2.2.tar.gz: IsoplotR/README.md <==
# IsoplotR

**IsoplotR** is a free and open-source substitute for Kenneth Ludwig's popular **Isoplot** add-in to Microsoft Excel. 
This Github repository contains the code for IsoplotR's core commands. A graphical user interface is provided
in a separate repository at [https://github.com/pvermees/IsoplotRgui](https://github.com/pvermees/IsoplotRgui).

## Prerequisites

You must have **R** installed on your system (see [http://r-project.org](http://r-project.org)). 
Additionally, to install IsoplotR from Github, you also need the **devtools** package.
This can be installed by typing the following code at the R command line prompt:

```
install.packages('devtools')
```

## Installation

The most recent stable version of IsoplotR is available from **CRAN** at
[https://cran.r-project.org/package=IsoplotR](https://cran.r-project.org/package=IsoplotR)
and can be installed on your system as follows:

```
install.packages('IsoplotR')
```

Alternatively, to install the current development version of IsoplotR from Github, type:

```
library(devtools)
install_github('pvermees/IsoplotR')
```

## Further information

See [http://isoplotr.london-geochron.com](http://isoplotr.london-geochron.com)

[Vermeesch, P., 2018, IsoplotR: a free and open toolbox for
geochronology. Geoscience Frontiers, v.9, p.1479-1493, doi: 10.1016/j.gsf.2018.04.001.](http://www.ucl.ac.uk/~ucfbpve/papers/VermeeschGSF2018/)

## Author

[Pieter Vermeesch](http://pieter.london-geochron.com)

## License

This project is licensed under the GPL-3 License
